@@ -16,8 +16,9 @@ def PrepareImage(dir, file_name=None):
   bar = ShadyBar('Image  Processing', max=len(os.listdir(dir)))
   for i, file in enumerate(os.listdir(dir)):
     path = pathlib.Path(dir + "/" + file)
-    if (path.suffix != '.jpg' and path.suffix != '.jpeg'):
-      path.unlink()
+    if os.path.isfile(path):
+      if (path.suffix != '.jpg' and path.suffix != '.jpeg'):
+        path.unlink()
     time.sleep(0.005)
     bar.next()
   bar.finish()
@@ -32,7 +33,9 @@ def RenameFiles(dir, file_name):
   os.getcwd()
   bar = ShadyBar('Rename Processing', max=len(os.listdir(dir)))
   for i, filename in enumerate(os.listdir(dir)):
-    os.rename(dir + "/" + filename, dir + "/"+ file_name + str(i) + ".jpg")
+    path = pathlib.Path(dir + "/" + filename)
+    if os.path.isfile(path):
+      os.rename(dir + "/" + filename, dir + "/"+ file_name + str(i) + ".jpg")
     time.sleep(0.005)
     bar.next()
   bar.finish()
@@ -49,7 +52,7 @@ def frames_to_video(inputpath, outputpath, fps=5):
   count = 0
   index = 0
   length = int(cap.get(cv2.CAP_PROP_FRAME_COUNT))
-  bar = ShadyBar('Image Create Processing', max=length//5 + 1)
+  bar = ShadyBar('Image Create Processing', max=video_frame_count(length, fps))
   while cap.isOpened():
     ret, frame = cap.read()
     if ret:
@@ -64,6 +67,11 @@ def frames_to_video(inputpath, outputpath, fps=5):
     time.sleep(0.005)
     bar.next()
   bar.finish()
+def video_frame_count(length, fps):
+  if length % fps == 0:
+    return length / fps
+  else:
+    return length//fps + 1
 # change image resolution
 def rescale_images(directory, height, width):
   bar = ShadyBar('Image Resize Processing', max=len(os.listdir(directory)))
@@ -74,4 +82,15 @@ def rescale_images(directory, height, width):
     im_resized.save(directory+'/'+img)
     time.sleep(0.005)
     bar.next()
-  bar.finish()
\ No newline at end of file
+  bar.finish()
+def MLDatasetBuilder():
+  text = colored(text2art("MLDatasetBuilder"), 'blue')
+  print(text)
+  print(colored('Welcome to MLDatasetBuilder ', 'blue') + colored(':)', 'blue', attrs=['blink']))
+  print(colored('Available Operations ', 'blue') + colored(':-', 'blue', attrs=['blink']))
+  print(colored('1) PrepareImage', 'grey', attrs=['bold']) + colored(' --> ', 'grey', attrs=['blink']) + colored('Remove unwanted format images and Rename image files.', 'blue', attrs=['bold']))
+  print("   " + colored('#PrepareImage(folder_name, image_name)', 'grey', attrs=['bold']))
+  print("   " + colored("PrepareImage('images', 'dog')", 'grey', attrs=['bold']))
+  print(colored('2) ExtractImages', 'grey', attrs=['bold']) + colored(' --> ', 'grey', attrs=['blink']) + colored('Extract images from video file', 'blue', attrs=['bold']))
+  print("   " + colored('#ExtractImages(video_path, file_name, frame_size)', 'grey', attrs=['bold']))
+  print("   " + colored("ExtractImages('video.mp4', 'frame', 10)", 'grey', attrs=['bold']))
